som.nn.export.kohonen: Export a som.nn model as object of type kohonen
Description
An existing model of type SOMnn is exported as
object of type kohonen for use with the tools of the
package kohonen.
Usage
som.nn.export.kohonen(model, train)
Value
Vist of type \code{kohonen} with the trained som.
See \code{\link[kohonen]{som}} for details.
Arguments
- model
model of type SOMnn.
- train
training data
Details
Training data is necessary to generate the kohonen object.